# eric7.WebBrowser.VirusTotal.VirusTotalWhoisDialog

Module implementing a dialog to show the 'whois' information.

### Global Attributes

None

### Classes

VirusTotalWhoisDialog | Class implementing a dialog to show the 'whois' information.

### Functions

None

## VirusTotalWhoisDialog

Class implementing a dialog to show the 'whois' information.

### Derived from

QDialog, Ui_VirusTotalWhoisDialog

### Class Attributes

None

### Class Methods

None

### Methods

VirusTotalWhoisDialog | Constructor

### Static Methods

None

#### VirusTotalWhoisDialog (Constructor)

VirusTotalWhoisDialog(domain, whois, parent=None)

Constructor

domain (str)
  domain name
whois (str)
  whois information
parent (QWidget)
  reference to the parent widget

Up